Method: HexData#data

Defined in:
lib/hexdata.rb

#dataArray

Note:

No copy of the array is created. If you edit the arrays, this affects the HexData class. If you want a copy of the array, you can, for example, use the .clone method.

Returns the records

Returns:

  • (Array)

    The records returned as an array



66
67
68
# File 'lib/hexdata.rb', line 66

def data
  @sets
end